@@ -29,7 +29,6 @@
 // include files for Qt
 #include <QApplication>
 #include <QBitmap>
-#include <QDesktopWidget>
 #include <QScrollBar>
 #include <QScreen>
 #include <QPainter>
@@ -642,6 +641,7 @@ void KMagZoomView::mouseReleaseEvent(QMouseEvent *e)
  */
 void KMagZoomView::mouseMoveEvent(QMouseEvent *e)
 {
+  const QSize screenSize = screen()->virtualSize();
   if(m_mouseMode == ResizeSelection) {
     // In resize selection mode
     // set the current mouse position as the bottom, right corner
@@ -660,17 +660,17 @@ void KMagZoomView::mouseMoveEvent(QMouseEvent *e)
     if(newCenter.x() < m_selRect.width()/2) {
       // set X to the minimum possible X
       newCenter.setX(m_selRect.width()/2);
-    } else if(newCenter.x() >=  QApplication::desktop()->width()-m_selRect.width()/2) {
+    } else if(newCenter.x() >=  screenSize.width()-m_selRect.width()/2) {
       // set X to the maximum possible X
-      newCenter.setX(QApplication::desktop()->width()-m_selRect.width()/2-1);
+      newCenter.setX(screenSize.width()-m_selRect.width()/2-1);
     }
 
     if(newCenter.y() < m_selRect.height()/2) {
       // set Y to the minimum possible Y
       newCenter.setY(m_selRect.height()/2);
-    } else if(newCenter.y() >=  QApplication::desktop()->height()-m_selRect.height()/2) {
+    } else if(newCenter.y() >=  screenSize.height()-m_selRect.height()/2) {
       // set Y to the maximum possible Y
-      newCenter.setY(QApplication::desktop()->height()-m_selRect.height()/2-1);
+      newCenter.setY(screenSize.height()-m_selRect.height()/2-1);
     }
     // move to the new center
     m_selRect.moveCenter(newCenter);
@@ -691,17 +691,17 @@ void KMagZoomView::mouseMoveEvent(QMouseEvent *e)
     if(newCenter.x() < m_selRect.width()/2) {
       // set X to the minimum possible X
       newCenter.setX(m_selRect.width()/2);
-    } else if(newCenter.x() >=  QApplication::desktop()->width()-m_selRect.width()/2) {
+    } else if(newCenter.x() >=  screenSize.width()-m_selRect.width()/2) {
       // set X to the maximum possible X
-      newCenter.setX(QApplication::desktop()->width()-m_selRect.width()/2-1);
+      newCenter.setX(screenSize.width()-m_selRect.width()/2-1);
     }
 
     if(newCenter.y() < m_selRect.height()/2) {
       // set Y to the minimum possible Y
       newCenter.setY(m_selRect.height()/2);
-    } else if(newCenter.y() >=  QApplication::desktop()->height()-m_selRect.height()/2) {
+    } else if(newCenter.y() >=  screenSize.height()-m_selRect.height()/2) {
       // set Y to the maximum possible Y
-      newCenter.setY(QApplication::desktop()->height()-m_selRect.height()/2-1);
+      newCenter.setY(screenSize.height()-m_selRect.height()/2-1);
     }
 
     // move to the new center
@@ -752,8 +752,9 @@ void KMagZoomView::keyPressEvent(QKeyEvent *e)
   {
     if (e->modifiers() & Qt::ControlModifier)
     {
-      if (m_selRect.right()+offset >= QApplication::desktop()->width())
-        m_selRect.setRight (QApplication::desktop()->width()-1);
+      const QSize screenSize = screen()->virtualSize();
+      if (m_selRect.right()+offset >= screenSize.width())
+        m_selRect.setRight (screenSize.width()-1);
       else
         m_selRect.setRight (m_selRect.right()+offset);
     }
@@ -767,8 +768,9 @@ void KMagZoomView::keyPressEvent(QKeyEvent *e)
     }
     else if (m_followMouse == false)
     {
-      if (m_selRect.right()+offset >= QApplication::desktop()->width())
-        m_selRect.moveTopRight (QPoint (QApplication::desktop()->width()-1, m_selRect.top()));
+      const QSize screenSize = screen()->virtualSize();
+      if (m_selRect.right()+offset >= screenSize.width())
+        m_selRect.moveTopRight (QPoint (screenSize.width()-1, m_selRect.top()));
       else
         m_selRect.translate (offset,0);
     }
@@ -804,8 +806,9 @@ void KMagZoomView::keyPressEvent(QKeyEvent *e)
   {
     if (e->modifiers() & Qt::ControlModifier)
     {
-      if (m_selRect.bottom()+offset >= QApplication::desktop()->height())
-        m_selRect.setBottom (QApplication::desktop()->height()-1);
+      const QSize screenSize = screen()->virtualSize();
+      if (m_selRect.bottom()+offset >= screenSize.height())
+        m_selRect.setBottom (screenSize.height()-1);
       else
         m_selRect.setBottom (m_selRect.bottom()+offset);
     }
@@ -819,8 +822,9 @@ void KMagZoomView::keyPressEvent(QKeyEvent *e)
     }
     else if (m_followMouse == false)
     {
-      if (m_selRect.bottom()+offset >= QApplication::desktop()->height())
-        m_selRect.moveBottomLeft (QPoint (m_selRect.left(), QApplication::desktop()->height()-1));
+      const QSize screenSize = screen()->virtualSize();
+      if (m_selRect.bottom()+offset >= screenSize.height())
+        m_selRect.moveBottomLeft (QPoint (m_selRect.left(), screenSize.height()-1));
       else
         m_selRect.translate (0, offset);
     }
@@ -872,22 +876,22 @@ void KMagZoomView::fitToWindow()
 
   m_selRect.setWidth(newWidth);
   m_selRect.setHeight(newHeight);
-
+  const QSize screenSize = screen()->virtualSize();
    // make sure the selection window does not go outside of the display
    if(currCenter.x() < m_selRect.width()/2) {
      // set X to the minimum possible X
      currCenter.setX(m_selRect.width()/2);
-   } else if(currCenter.x() >=  QApplication::desktop()->width()-m_selRect.width()/2) {
+   } else if(currCenter.x() >=  screenSize.width()-m_selRect.width()/2) {
      // set X to the maximum possible X
-     currCenter.setX(QApplication::desktop()->width()-m_selRect.width()/2-1);
+     currCenter.setX(screenSize.width()-m_selRect.width()/2-1);
    }
 
    if(currCenter.y() < m_selRect.height()/2) {
      // set Y to the minimum possible Y
      currCenter.setY(m_selRect.height()/2);
-   } else if(currCenter.y() >=  QApplication::desktop()->height()-m_selRect.height()/2) {
+   } else if(currCenter.y() >=  screenSize.height()-m_selRect.height()/2) {
      // set Y to the maximum possible Y
-     currCenter.setY(QApplication::desktop()->height()-m_selRect.height()/2-1);
+     currCenter.setY(screenSize.height()-m_selRect.height()/2-1);
    }
 
   m_selRect.moveCenter(currCenter);
@@ -935,20 +939,21 @@ void KMagZoomView::grabFrame()
 
     // make sure the mouse position is not taking the grab window outside
     // the display
+    const QSize screenSize = screen()->virtualSize();
     if(newCenter.x() < m_selRect.width()/2) {
       // set X to the minimum possible X
       newCenter.setX(m_selRect.width()/2);
-    } else if(newCenter.x() >=  QApplication::desktop()->width()-m_selRect.width()/2) {
+    } else if(newCenter.x() >=  screenSize.width()-m_selRect.width()/2) {
       // set X to the maximum possible X
-      newCenter.setX(QApplication::desktop()->width()-m_selRect.width()/2-1);
+      newCenter.setX(screenSize.width()-m_selRect.width()/2-1);
     }
 
     if(newCenter.y() < m_selRect.height()/2) {
       // set Y to the minimum possible Y
       newCenter.setY(m_selRect.height()/2);
-    } else if(newCenter.y() >=  QApplication::desktop()->height()-m_selRect.height()/2) {
+    } else if(newCenter.y() >=  screenSize.height()-m_selRect.height()/2) {
       // set Y to the maximum possible Y
-      newCenter.setY(QApplication::desktop()->height()-m_selRect.height()/2-1);
+      newCenter.setY(screenSize.height()-m_selRect.height()/2-1);
     }
     // move to the new center
     m_selRect.moveCenter(newCenter);
@@ -962,7 +967,8 @@ void KMagZoomView::grabFrame()
 
   // grab screenshot from the screen and put it in the pixmap
   QScreen *screen = qApp->primaryScreen(); // ## How to select the right screen?
-  m_coloredPixmap = screen->grabWindow(QApplication::desktop()->winId(), selRect.x(), selRect.y(),
+  m_coloredPixmap = screen->grabWindow(0,  // WId == 0 is interpreted as the root window / desktop
+                                      selRect.x(), selRect.y(),
                                       selRect.width(), selRect.height());
 
   // colorize the grabbed pixmap
